def get_env(tempfile):
    import os

    pyvterm_dump_json(
        tempfile,
        dict(
            env=["=".join(el) for el in list(os.environ.items())],
            cwd=os.getcwd(),
        ),
    )



def delete_history(tmpfile, num):
    try:
        if not __IPYTHON__:
            pyvterm_dump_json(tmpfile, False)
            return

        hismgr = get_ipython().history_manager
        hismgr.db.execute(
            "DELETE from history where rowid in (Select rowid FROM history WHERE session={0} order by line DESC LIMIT {1})".format(
                hismgr.get_last_session_id(), num
            )
        )
        del hismgr
        pyvterm_dump_json(tmpfile, True)

    except NameError:
        pyvterm_dump_json(tmpfile, True)



"""Import all public names from a module into the current namespace."""


def star_import_script(tmpfile, path):
    import importlib, pathlib, sys

    name = pathlib.Path(path).stem
    spec = importlib.util.spec_from_file_location(name, path)
    mdl = importlib.util.module_from_spec(spec)
    sys.modules[name] = mdl
    spec.loader.exec_module(mdl)

    if "__all__" in mdl.__dict__:
        names = mdl.__dict__["__all__"]
    else:
        names = [x for x in mdl.__dict__ if not x.startswith("_")]

    # now drag them in
    globals().update({k: getattr(mdl, k) for k in names})

    pyvterm_dump_json(tmpfile, True)
